import { __decorate } from "tslib";
import { GridProRendererTypes, getActionsMenuDef } from '@genesislcap/foundation-zero-grid-pro';
import { bodyFont } from '@microsoft/fast-components';
import { attr, customElement, DOM, FASTElement, observable } from '@microsoft/fast-element';
import { defaultBodyFont, EventName } from '../../types';
import { applyStyleChanges } from '../../utils/utils';
import { sampleRowData } from './data/sampleRowData';
import { PreviewGridStyles as styles } from './preview-grid.styles';
import { PreviewGridTemplate as template } from './preview-grid.template';
let PreviewGrid = class PreviewGrid extends FASTElement {
    constructor() {
        super(...arguments);
        this.prefix = 'zero';
        this.rowData = [...sampleRowData];
        this.columnDefs = [
            { headerName: '#', colId: 'rowNum', valueGetter: 'node.id', width: 80, pinned: 'left' },
            { headerName: 'Athlete', field: 'athlete', width: 150, pinned: 'left' },
            { headerName: 'Age', field: 'age', width: 90, pinned: 'left' },
            { headerName: 'Country', field: 'country', width: 150 },
            { headerName: 'Year', field: 'year', width: 90 },
            {
                headerName: 'Date',
                field: 'date',
                width: 110,
                filter: 'agDateColumnFilter',
                filterParams: {
                    buttons: ['apply', 'reset'],
                    browserDatePicker: true,
                    comparator: (filterLocalDateAtMidnight, cellValue) => {
                        // Handling '29/08/2004' date format - adjust as need to match your date format
                        // https://www.ag-grid.com/javascript-data-grid/filter-date/
                        const dateAsString = cellValue;
                        if (dateAsString == null)
                            return -1;
                        const dateParts = dateAsString.split('/');
                        const cellDate = new Date(Number(dateParts[2]), Number(dateParts[1]) - 1, Number(dateParts[0]));
                        if (filterLocalDateAtMidnight.getTime() === cellDate.getTime()) {
                            return 0;
                        }
                        if (cellDate < filterLocalDateAtMidnight) {
                            return -1;
                        }
                        if (cellDate > filterLocalDateAtMidnight) {
                            return 1;
                        }
                        return 0;
                    },
                },
            },
            { headerName: 'Sport', field: 'sport', width: 150, editable: true },
            { headerName: 'Gold', field: 'gold', width: 100 },
            { headerName: 'Silver', field: 'silver', width: 100 },
            { headerName: 'Bronze', field: 'bronze', width: 100 },
            { headerName: 'Total', field: 'total', width: 100, pinned: 'right' },
        ];
        this.gridOptions = {
            defaultColDef: {
                resizable: true,
                filter: true,
            },
            debug: false,
            columnDefs: this.columnDefs,
            rowData: this.rowData,
        };
        this.myCustomCheckboxRenderer = (params) => {
            // eslint-disable-next-line @typescript-eslint/no-magic-numbers
            if (params.value === 2012) {
                return `<div><span style="color: var(--warning-color); font-weight: bold;">${params.value}</span></div>`;
            }
            return params.value;
        };
        this.multipleCustomFoundationColumnConfigs = [
            {
                headerName: 'Country',
                field: 'country',
                cellRenderer: GridProRendererTypes.boolean,
            },
            {
                headerName: 'Year',
                field: 'year',
                cellRenderer: this.myCustomCheckboxRenderer,
            },
        ];
        this.multipleActions = [
            {
                name: 'View',
                callback: (rowData) => console.log('VIEWW!!!', rowData),
            },
            {
                name: 'Delete',
                callback: (rowData) => console.log('DELETE!!!', rowData),
            },
            {
                name: 'Edit',
                callback: (rowData) => console.log('EDIT!!!', rowData),
            },
            {
                name: 'Wait',
                callback: (rowData) => console.log('WHAT???', rowData),
            },
        ];
        this.multipleActionsMenuSlottedConfig = getActionsMenuDef(this.multipleActions, {
            headerName: 'Multiple Actions',
            width: 140,
        }, '⋮', true, 'stealth');
        this.singleActionSlottedConfig = {
            headerName: 'Single Action',
            width: 200,
            cellRenderer: GridProRendererTypes.action,
            cellRendererParams: {
                actionClick: (rowData) => console.log('CLICKED ON SINGLE ACTION!!!!', rowData),
                actionName: 'Single Action',
                appearance: 'accent',
                isDisabled: (rowData) => {
                    return !!rowData.isActionDisabled;
                },
                dataTestId: 'singleActionTestId#',
                uniqueFieldName: 'UNIQUE_ID',
            },
        };
    }
    setGridOptions() {
        this.grid.gridOptions = this.gridOptions;
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            this.handleStyleChanges(e);
        });
        document.body.addEventListener(EventName.DS_CHANGED, (e) => {
            this.handleDSChanges(e);
        });
        DOM.queueUpdate(() => {
            this.setGridOptions();
            bodyFont.withDefault(defaultBodyFont);
        });
    }
    handleStyleChanges(e) {
        const detail = e.detail;
        if (detail) {
            DOM.queueUpdate(() => {
                applyStyleChanges(detail, this.provider);
            });
        }
    }
    handleDSChanges(event) {
        this.prefix = event.detail.prefix;
        DOM.queueUpdate(() => {
            this.setGridOptions();
        });
    }
};
__decorate([
    observable
], PreviewGrid.prototype, "grid", void 0);
__decorate([
    attr
], PreviewGrid.prototype, "prefix", void 0);
__decorate([
    observable
], PreviewGrid.prototype, "provider", void 0);
__decorate([
    observable
], PreviewGrid.prototype, "rowData", void 0);
__decorate([
    observable
], PreviewGrid.prototype, "columnDefs", void 0);
__decorate([
    observable
], PreviewGrid.prototype, "gridOptions", void 0);
PreviewGrid = __decorate([
    customElement({
        name: 'preview-grid',
        template,
        styles,
    })
], PreviewGrid);
export { PreviewGrid };
